package com.infoly.eclipse.xtext.algo.ui.highlighting

import org.eclipse.xtext.ui.editor.syntaxcoloring.DefaultHighlightingConfiguration
import org.eclipse.xtext.ui.editor.syntaxcoloring.IHighlightingConfigurationAcceptor
import org.eclipse.swt.SWT
import org.eclipse.xtext.ui.editor.utils.TextStyle
import org.eclipse.swt.graphics.RGB

class AlgorithmicHighlightingConfiguration extends DefaultHighlightingConfiguration {
	val public static TYPE_PRIMITIF_ID 	 = "typePrimitif"
	val public static TYPE_STRUCTURED_ID = "typeStructured"
	val public static TYPE_USER_ID 	 	 = "typeUser"
  	val public static CONST_GLOB_ID 	 = "constGlob"
  	val public static VAR_GLOB_ID 		 = "varGlob"
  	val public static CONST_LOC_ID 		 = "constLoc"
  	val public static VAR_LOC_ID 		 = "varLoc"
  	val public static FIELD_CONST_GLOB_ID = "fieldConstGlob"
  	val public static FIELD_CONST_LOC_ID = "fieldConstLoc"
  	val public static FIELD_VAR_GLOB_ID  = "fieldVarGlob"
  	val public static FIELD_VAR_LOC_ID 	 = "fieldVarLoc"

  	val public static MODULE_NAME_ID 	 = "moduleName"
  	val public static MODULE_TYPE_ID 	 = "moduleType"
  	val public static LIBRARY_NAME_ID	 = "libraryName"
  	val public static ALGO_ERROR_ID 	 = "algoError"
  	val public static TEST_ID 			 = "test"
  	val public static TEST2_ID 			 = "test2"
  	val public static TEST3_ID 			 = "test3"
  	
  	val public static RGB_COLOR_DARK_CYAN = new RGB( 0, 127, 127)
  	val public static RGB_COLOR_DARK_GREY = new RGB( 64, 64, 64)
  	val public static RGB_COLOR_GREY 	  = new RGB( 128, 128, 128)
  	val public static RGB_COLOR_RED		  = new RGB( 255, 0, 0)
   	val public static RGB_COLOR_YELLOW	  = new RGB( 255, 255, 0)
    val public static RGB_COLOR_GREEN	  = new RGB( 0, 255, 0)
    val public static RGB_COLOR_DARK_KAKI = new RGB(122,102,0)
    val public static RGB_COLOR_KAKI 	  = new RGB(153,169,0)
      	
	override configure(IHighlightingConfigurationAcceptor acceptor) {
		super.configure(acceptor)
		acceptor.acceptDefaultHighlighting(TYPE_PRIMITIF_ID, "Type Primitif", typePrimitifTextStyle )
		acceptor.acceptDefaultHighlighting(TYPE_STRUCTURED_ID, "Type Structured", typeStructuredTextStyle )
		acceptor.acceptDefaultHighlighting(TYPE_USER_ID, "Type User", typeUserTextStyle )
		
		acceptor.acceptDefaultHighlighting(CONST_GLOB_ID, "Constante Glob.", constGlobTextStyle )
		acceptor.acceptDefaultHighlighting(VAR_GLOB_ID, "Variable Glob.", varGlobTextStyle )
		acceptor.acceptDefaultHighlighting(CONST_LOC_ID, "Constante Loc.", constLocTextStyle )
		acceptor.acceptDefaultHighlighting(VAR_LOC_ID, "Variable Loc.", varLocTextStyle )
		acceptor.acceptDefaultHighlighting(FIELD_CONST_GLOB_ID, "Field Const.", fieldConstGlobTextStyle )
		acceptor.acceptDefaultHighlighting(FIELD_CONST_LOC_ID, "Field Const.", fieldConstLocTextStyle )
		acceptor.acceptDefaultHighlighting(FIELD_VAR_GLOB_ID, "Field Var.", fieldVarGlobTextStyle )
		acceptor.acceptDefaultHighlighting(FIELD_VAR_LOC_ID, "Field Var.", fieldVarLocTextStyle )
		acceptor.acceptDefaultHighlighting(LIBRARY_NAME_ID, "Library Name", libraryTextStyle )
		acceptor.acceptDefaultHighlighting(MODULE_TYPE_ID, "Module Type", moduleTypeTextStyle )
		acceptor.acceptDefaultHighlighting(MODULE_NAME_ID, "Module Name", moduleNameTextStyle )
		acceptor.acceptDefaultHighlighting(ALGO_ERROR_ID, "Algo Error", algoErrorTextStyle )
		
//		acceptor.acceptDefaultHighlighting(TEST_ID, "Test", testTextStyle )
//		acceptor.acceptDefaultHighlighting(TEST2_ID, "Test 2", test2TextStyle )
//		acceptor.acceptDefaultHighlighting(TEST3_ID, "Test 3", test3TextStyle )
	}
				
	def typePrimitifTextStyle() {						// Type Primitif : Gras + Magenta
		var textStyle =  keywordTextStyle.copy  		// A partir d'un TextStyle (keywordTextStyle) existant
		return textStyle
	}
 	
	def typeStructuredTextStyle() {						// Type Structured : Gras + Magenta
		var textStyle =  keywordTextStyle.copy  		// A partir d'un TextStyle (keywordTextStyle) existant
		return textStyle
	}
 	
	def typeUserTextStyle() {							// Types Utilisateur : Gras + Italic + Magenta
		var textStyle =  keywordTextStyle.copy  		// A partir d'un TextStyle (keywordTextStyle) existant
		textStyle.style = textStyle.style + SWT.ITALIC  // Ajout de l'attribut ITALIC au style 
		return textStyle
	}
 	
 	def constGlobTextStyle() {							// Data : Gras + Gris fonc
		var textStyle =  keywordTextStyle.copy  		// A partir d'un TextStyle (keywordTextStyle) existant
		textStyle.style = textStyle.style + SWT.ITALIC  // Ajout de l'attribut ITALIC au style 
		textStyle.color = RGB_COLOR_DARK_GREY 			// RGB COLOR_DARK_GREY  : Modification de la couleur
		return textStyle
 	}
	
 	def varGlobTextStyle() {							// Data : Gras + Gris fonc
		var textStyle =  keywordTextStyle.copy  		// A partir d'un TextStyle (keywordTextStyle) existant
		textStyle.style = textStyle.style + SWT.ITALIC  // Ajout de l'attribut ITALIC au style 
		textStyle.color = RGB_COLOR_GREY 				// RGB COLOR_GREY 
		return textStyle
 	}
	
 	def constLocTextStyle() {							// Data : Gras + Gris 
		var textStyle =  keywordTextStyle.copy  		// A partir d'un TextStyle (keywordTextStyle) existant
		textStyle.color = RGB_COLOR_DARK_GREY 				// RGB COLOR_GREY 
		return textStyle
 	}
	
 	def varLocTextStyle() {								// Data : Gras + Gris 
		var textStyle =  keywordTextStyle.copy  		// A partir d'un TextStyle (keywordTextStyle) existant
		textStyle.color = RGB_COLOR_GREY 				// RGB COLOR_GREY 
		return textStyle
 	}
	
	def moduleTypeTextStyle() {							// Module Type : Gras + Magenta
		var textStyle =  keywordTextStyle.copy  		// A partir d'un TextStyle (keywordTextStyle) existant
		return textStyle
	}
 	
 	def libraryTextStyle() {							// Library Name : Gras + Italic + Dark Cyan 
		var textStyle =  keywordTextStyle.copy			// Cration d'un nouveau TextStyle
		textStyle.color =  RGB_COLOR_DARK_CYAN	 		// RGB COLOR_DARK_CYAN 
		return textStyle
 	}
 	
	def moduleNameTextStyle() {							// Module Name : Library Name + Italique
		var textStyle =  libraryTextStyle.copy			// Cration d'un nouveau TextStyle
		textStyle.style = textStyle.style + SWT.ITALIC		
		return textStyle
	}
	
  	def fieldConstLocTextStyle() {				// Field Name : Gras + Italic + Magenta + Gris Clair
		var textStyle =  constLocTextStyle.copy 
		textStyle.color = RGB_COLOR_DARK_KAKI
		return textStyle 
 	}

  	def fieldConstGlobTextStyle() {				// Field Name : Gras + Italic + Magenta + Gris Clair
		var textStyle =  fieldConstLocTextStyle.copy 
		textStyle.style = textStyle.style + SWT.ITALIC		
		return textStyle 
 	}

  	def fieldVarLocTextStyle() {				// Field Name : Gras + Italic + Magenta + Gris Clair
		var textStyle =  varLocTextStyle.copy 
		textStyle.color =  RGB_COLOR_KAKI
		return textStyle
 	}

  	def fieldVarGlobTextStyle() {				// Field Name : Gras + Italic + Magenta + Gris Clair
		var textStyle =  fieldVarLocTextStyle.copy 
		textStyle.style = textStyle.style + SWT.ITALIC		
		return textStyle
 	}
 
 	def algoErrorTextStyle() {
 		var textStyle =  new TextStyle			// Cration d'un nouveau TextStyle
		textStyle.style =  textStyle.style + SWT.BOLD 
		textStyle.backgroundColor = RGB_COLOR_RED  	// RGB COLOR_RED
		textStyle.color = RGB_COLOR_YELLOW  		// RGB COLOR_YELLOW
		return textStyle
 	}

/*
 	def testTextStyle() {
 		var textStyle =  new TextStyle			// Cration d'un nouveau TextStyle
		textStyle.style =  textStyle.style + SWT.BOLD 
		textStyle.color = RGB_COLOR_RED  		// RGB COLOR_YELLOW
		return textStyle
 	}
	
 	def test2TextStyle() {
 		var textStyle =  new TextStyle			// Cration d'un nouveau TextStyle
		textStyle.style = textStyle.style + SWT.BOLD 
		textStyle.style = textStyle.style + SWT.ITALIC 
		textStyle.backgroundColor = RGB_COLOR_RED 
		textStyle.color = RGB_COLOR_YELLOW 		// RGB COLOR_YELLOW
		return textStyle
 	}
	
 	def test3TextStyle() {
 		var textStyle =  new TextStyle			// Cration d'un nouveau TextStyle
		textStyle.style = textStyle.style + SWT.BOLD 
		textStyle.backgroundColor = RGB_COLOR_YELLOW
		textStyle.color =  RGB_COLOR_RED 		// RGB COLOR_YELLOW
		return textStyle
 	}
	 */
	 
}


