package com.infoly.eclipse.xtext.algo.ui.highlighting

import org.eclipse.emf.ecore.EObject
import org.eclipse.xtext.ide.editor.syntaxcoloring.IHighlightedPositionAcceptor
import org.eclipse.xtext.ide.editor.syntaxcoloring.ISemanticHighlightingCalculator
import org.eclipse.xtext.nodemodel.ICompositeNode
import org.eclipse.xtext.nodemodel.util.NodeModelUtils
import org.eclipse.xtext.resource.XtextResource
import org.eclipse.xtext.util.CancelIndicator
import com.infoly.eclipse.xtext.algo.algorithmic.TypeName
import com.infoly.eclipse.xtext.algo.algorithmic.TypeUser
import com.infoly.eclipse.xtext.algo.algorithmic.ConstName
import com.infoly.eclipse.xtext.algo.algorithmic.VarName
import com.infoly.eclipse.xtext.algo.algorithmic.ModuleFunction
import com.infoly.eclipse.xtext.algo.algorithmic.ModuleProcedure
import com.infoly.eclipse.xtext.algo.algorithmic.ModuleRef
import com.infoly.eclipse.xtext.algo.algorithmic.DataRef
import com.infoly.eclipse.xtext.algo.algorithmic.Algorithmic
import com.infoly.eclipse.xtext.algo.algorithmic.LibraryName
import com.infoly.eclipse.xtext.algo.algorithmic.VarRef

/*
 **************************************************************
 * RESTE A VOIR LA COLORATION POUR LES CHAMPS ET LES PARAMETRES
 **************************************************************
 */

class AlgorithmicSemanticHighlightingCalculator implements ISemanticHighlightingCalculator {
	
	override provideHighlightingFor(XtextResource arg0, IHighlightedPositionAcceptor arg1, CancelIndicator arg2) {
		var root = arg0.contents.get(0)
		var eAllContents = root.eAllContents
		
		var acceptor = arg1
		var object = null as  EObject
		var node = null as ICompositeNode	
		
		var global = true

		while ( eAllContents.hasNext ) {
			object = eAllContents.next 
			node = NodeModelUtils.findActualNodeFor(object)
			var offset = node.offset
			var length = node.length   	

			switch (object)	{
			
				TypeName, TypeUser : 
					acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.TYPE_USER_ID )
				ConstName : 
					if ( global )
						acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.CONST_GLOB_ID )  // Const Global
					else
						acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.CONST_LOC_ID )  // Const Local
				VarName:
					if ( global )
						acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.VAR_GLOB_ID )  	// Var Global
					else
						acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.VAR_LOC_ID )  	// Var Local
 				ModuleFunction : {
					var pos=(object as ModuleFunction).module.literal.length+1	
					acceptor.addPosition( offset+pos, object.name.name.length, AlgorithmicHighlightingConfiguration.MODULE_NAME_ID )
					global = false
				}
				ModuleProcedure : { 	
					var pos=(object as ModuleProcedure).module.literal.length+1	
					acceptor.addPosition( offset+pos, object.name.name.length, AlgorithmicHighlightingConfiguration.MODULE_NAME_ID )
					global = false
				}
				ModuleRef : 
					acceptor.addPosition( offset, object.ref.name.length, AlgorithmicHighlightingConfiguration.MODULE_NAME_ID )
				VarRef  : 
					if (object.ref.eContainer.eContainer.eContainer.eContainer instanceof Algorithmic )
						acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.VAR_GLOB_ID )  	// Var Global
					else
						acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.VAR_LOC_ID )  	// Var Local
				DataRef:	
					if (object.ref instanceof ConstName)
						if (object.ref.eContainer.eContainer.eContainer.eContainer instanceof Algorithmic )
							acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.CONST_GLOB_ID )  	// Const Global
						else
							acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.CONST_LOC_ID )  	// Const Local
					else
						if (object.ref.eContainer.eContainer.eContainer.eContainer instanceof Algorithmic )
							acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.VAR_GLOB_ID )  	// Var Global
						else
							acceptor.addPosition( offset, length, AlgorithmicHighlightingConfiguration.VAR_LOC_ID )  	// Var Local				
				LibraryName :   	
					acceptor.addPosition( offset, object.name.literal.length, AlgorithmicHighlightingConfiguration.LIBRARY_NAME_ID )								
			}
			
		}		
 	}
}

/* 	
	def private isGlobal( EObject obj ) {
	
     	   obj.eContainer.eContainer.eContainer.eContainer instanceof Algorithmic						 // Pour les Datas
		|| obj.eContainer.eContainer.eContainer.eContainer.eContainer instanceof Algorithmic  			 // Pour les Paramtres
		|| obj.eContainer.eContainer.eContainer.eContainer.eContainer.eContainer instanceof Algorithmic  // Pour les champs

     	!( obj.eContainer.eContainer.eContainer.eContainer instanceof Module						 // Pour les Datas
		|| obj.eContainer.eContainer.eContainer.eContainer.eContainer instanceof Module  			 // Pour les Paramtres
		|| obj.eContainer.eContainer.eContainer.eContainer.eContainer.eContainer instanceof Module  // Pour les champs
     	
		var b = false
     	val b1 = obj.eContainer.eContainer.eContainer.eContainer instanceof Module						 // Pour les Datas
		val b2 = obj.eContainer.eContainer.eContainer.eContainer.eContainer instanceof Module  			 // Pour les Paramtres
		val b3 =  obj.eContainer.eContainer.eContainer.eContainer.eContainer.eContainer instanceof Module  // Pour les champs
		b = !(b1 || b2 || b3)
	}

*/

